| .second_moa_ring | R Documentation |
Computes the second areal moment for a single ring
.second_moa_ring(coords, centroid)
coords |
A matrix of coordinates for a ring |
centroid |
Centroid coordinates, supplied as an object of class sf, sfc, or sfg |
A single number, giving the second areal moment for a ring
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.