dot-second_moment_single_geom: Second areal moment for a single geometry

.second_moment_single_geomR Documentation

Second areal moment for a single geometry

Description

Computes the second areal moment for a single geometry (POLYGON or MULTIPOLYGON)

Usage

.second_moment_single_geom(geom)

Arguments

geom

A simple feature geometry

Value

A single number, giving the second areal moment for the geometry


spopt documentation built on April 22, 2026, 9:07 a.m.