rust_distance_matrix_manhattan: Compute Manhattan distance matrix between two sets of points

View source: R/extendr-wrappers.R

rust_distance_matrix_manhattanR Documentation

Compute Manhattan distance matrix between two sets of points

Description

Compute Manhattan distance matrix between two sets of points

Usage

rust_distance_matrix_manhattan(x1, y1, x2, y2)

Arguments

x1

X coordinates of first set of points

y1

Y coordinates of first set of points

x2

X coordinates of second set of points

y2

Y coordinates of second set of points

Value

Distance matrix (n1 x n2)


spopt documentation built on April 22, 2026, 9:07 a.m.