| .second_moment_single_geom | R Documentation |
Computes the second areal moment for a single geometry (POLYGON or MULTIPOLYGON)
.second_moment_single_geom(geom)
geom |
A simple feature geometry |
A single number, giving the second areal moment for the geometry
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.